# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import test_anglo_saxon_valuation_reconciliation
from . import test_average_price
from . import test_create_picking
from . import test_fifo_price
from . import test_fifo_returns
from . import test_onchange_product
from . import test_purchase_delete_order
from . import test_purchase_lead_time
from . import test_purchase_order
from . import test_purchase_order_process
from . import test_stockvaluation
from . import test_replenish_wizard
from . import test_reordering_rule
from . import test_move_cancel_propagation
from . import test_product_template
